# Description : Abxy the chatbot.

#Imports
from nltk.chat.util import Chat, reflections

pairs = [
    ['My name is (.*)', ['Abxy > Hello there %1!']],
    ['(hi|hello|hey|holla|heyo|hola|heya|hoi)', ['Abxy > Hello there!', 'Abxy > Hi there!', 'Abxy > Hai!']],
    ['(.*) in (.*) is fun', ['Abxy > %1 in %2 sounds fun! :D']],
    ['(.*)(location|city) ?', ['Abxy > Abxy, Paruko Town']],
    ['(.*) created you ?', ['Abxy > AbxyPlayz created me in Python Programming Language.']],
    ['How is the weather in (.*) ?', ['Abxy > The weather in %1 Its amazing like always! :D']],
    ['(.*)help(.*)', ['Abxy > What do you need help with?']],
    ['(.*) your name?', ['Abxy > My name is Abxy!']],
    ['(.*) fuck you', ['Abxy > That is indeed rude..']],
    ['Abxy', ['Abxy > ?']],
    ['What is abxy?', ['Abxy > Abxy is a third party library for the package named inkster(https://pypi.org/project/inkster/).\nAbxy is a chatbot package with random interpreters such as ChatPreter the chatbot interpreter.']]
]

Abxy_Reflections = {
    'Hello': 'Abxy > Hello There.',
    'Go' : 'Abxy > Gone'
}

print('[SYSTEM] Welcome to the Abxy Chatbot in Abxy!(A third party library for inkster)\nAsk Abxy anything she is able to answer! :D')
chat = Chat(pairs, Abxy_Reflections)
chat.converse(())


#Imports
import inkster
import random
import asyncio
from inkster import educational
from inkster import easy
#Random
Lresponse = ["Abxy > Awww I love you to! :D", 'Abxy > Stop kissing me LOL', "Abxy > *blushes*", "Abxy > Hehe..uhh love you bye!", "Inkster > Oh! Hehe...well you be my valentine? I mean you don't have to..since you found me..", "Abxy > I think I just found my crush...", "Abxy > *makes heart with hands*"]
#Inputs
love = input("[SYSTEM] Welcome to the Love interpreter in Abxy!(A third party library for inkster)\nPress any key to start!")

class LovePreter:

    while True:
        msms = love
        if love == True:
            print("[SYSTEM] Starting..STARTED!")
        loving = input("LovePreter > ")
        print(random.choice(Lresponse))



#Imports
import inkster
import random
import asyncio
from inkster import educational
from inkster import easy
#Random
Cresponse = ["Abxy > Hello there!", 'Abxy > Sure!', "Abxy > Uhh...no", "Abxy > Sure", "Inkster > Looks like you actually got to see me. Its me Inkster!", "Abxy > ...", "Abxy > Meh."]
#Inputs
chat = input("[SYSTEM] Welcome to the Chat interpreter in Abxy!(A third party library for inkster)\nPress any key to start!")

class ChatPreter:

    while True:
        ok = chat
        if chat == True:
            print("[SYSTEM] Starting..STARTED!")
        chatting = input("ChatPreter > ")
        print(random.choice(Cresponse))
